@@ -151,7 +151,7 @@ txtPval <- function(pvalues,
   sapply(pvalues, function(x, lim.2dec, lim.sig, lt_sign){
     if (is.na(as.numeric(x))){
       warning("The value: '", x, "' is non-numeric and txtPval",
-              " can't therfore handle it")
+              " can't therefore handle it")
       return (x)
     }
 
@@ -186,6 +186,7 @@ txtPval <- function(pvalues,
 #' @param dec The decimal marker. If the text is in non-english decimal
 #'  and string formatted you need to change this to the apropriate decimal
 #'  indicator.
+#' @param scientific If the value should be in scientific format.
 #' @param ... Passed to next method
 #' @return \code{matrix/data.frame}
 #'
@@ -204,7 +205,12 @@ txtRound <- function(x, ...){
 
 #' @export
 #' @rdname txtRound
-txtRound.default = function(x, digits = 0, txt.NA = "", dec = ".", ...){
+txtRound.default = function(x,
+                            digits = 0,
+                            txt.NA = "",
+                            dec = ".",
+                            scientific,
+                            ...){
   if(length(digits) != 1 & length(digits) != length(x))
     stop("You have ",
          length(digits),
@@ -213,17 +219,25 @@ txtRound.default = function(x, digits = 0, txt.NA = "", dec = ".", ...){
          ": ",
          paste(x, collapse=", "))
 
-  dec_str <- sprintf("^[^0-9\\%s-]*([\\-]{0,1}(([0-9]*|[0-9]+[ 0-9]+)[\\%s]|)[0-9]+)(|[^0-9]+.*)$",
+  if (length(x) > 1) {
+    return(mapply(txtRound.default, x, digits, txt.NA, dec, ...))
+  }
+
+  dec_str <- sprintf("^[^0-9\\%s-]*([\\-]{0,1}(([0-9]*|[0-9]+[ 0-9]+)[\\%s]|)[0-9]+(e[+]{0,1}[0-9]+|))(|[^0-9]+.*)$",
                      dec, dec)
   if (is.na(x))
     return(txt.NA)
   if (!is.numeric(x) &&
       !grepl(dec_str, x))
     return(x)
+
   if (is.character(x) &&
       grepl(dec_str, x)){
     if (dec != ".")
       x <- gsub(dec, ".", x)
+    if (grepl("[0-9.]+e[+]{0,1}[0-9]+", x) && missing(scientific)) {
+      scientific <- TRUE
+    }
 
     # Select the first occurring number
     # remove any spaces indicating thousands
@@ -234,11 +248,15 @@ txtRound.default = function(x, digits = 0, txt.NA = "", dec = ".", ...){
       as.numeric
   }
 
-  mapply(function(v, d){
-    if (round(v, d) == 0)
-      v <- 0
-    sprintf(paste0("%.", d, "f"), v)
-  }, x, digits)
+  if (round(x, digits) == 0)
+    x <- 0
+
+  if (!missing(scientific) && scientific) {
+    x <- round(x, digits)
+    return(format(x, scientific = TRUE))
+  }
+
+  sprintf(paste0("%.", digits, "f"), x)
 }
 
 #' @export
@@ -255,6 +273,64 @@ txtRound.data.frame <- function(x, ...){
   return (as.data.frame(x, stringsAsFactors = FALSE))
 }
 
+#' @rdname txtRound
+#' @export
+txtRound.table <- function(x, ...){
+  return(txtRound.matrix(x, ...))
+}
+
+#' @rdname txtRound
+#' @export
+txtRound.matrix <- function(x, digits = 0, excl.cols, excl.rows, ...){
+  if(length(dim(x)) > 2)
+    stop("The function only accepts vectors/matrices/data.frames as primary argument")
+
+  rows <- 1L:nrow(x)
+  if (!missing(excl.rows)){
+    if (is.character(excl.rows)){
+      excl.rows <- grep(excl.rows, rownames(x))
+    }
+
+    if (length(excl.rows) > 0)
+      rows <- rows[-excl.rows]
+  }
+
+  cols <- 1L:ncol(x)
+  if (!missing(excl.cols)){
+    if (is.character(excl.cols)){
+      excl.cols <- grep(excl.cols, colnames(x))
+    }
+
+    if (length(excl.cols) > 0)
+      cols <- cols[-excl.cols]
+  }
+
+  if (length(cols) == 0)
+    stop("No columns to round")
+
+  if (length(rows) == 0)
+    stop("No rows to round")
+
+  if(length(digits) != 1 & length(digits) != length(cols))
+    stop("You have ",
+         length(digits),
+         " digits specifications but ",
+         length(cols),
+         " columns to apply them to: ",
+         paste(cols, collapse = ", "))
+
+  ret_x <- x
+  for (row in rows){
+    ret_x[row, cols] <-
+      mapply(txtRound, x[row, cols], digits,
+             ...,
+             USE.NAMES = FALSE)
+  }
+
+  return(ret_x)
+}
+
+
 #' @rdname txtRound
 #' @export
 txtRound.matrix <- function(x, digits = 0, excl.cols, excl.rows, ...){
