@@ -128,16 +128,32 @@ test_that("Supplying a data.frame",{
                test_df$text)
 })
 
+test_that("Supplying a table",{
+  out <- txtRound(table(1:4, 4:1))
+  expect_equal(nrow(out), 4)
+  expect_equal(ncol(out), 4)
+})
+
 test_that("Supplying a vector for the digits",{
   w <- matrix((1:8)/7, ncol=4)
   w_out <- txtRound(w, digits=1:4)
-  txtRound
   for (digits in 1:4)
     expect_equivalent(w_out[,digits],
                       sprintf(paste0("%.", digits, "f"), w[,digits]),
                       paste("Expected the number of digits to be", digits))
 })
 
+test_that("The txtRound should accept without warning a vector",{
+  w <- c(.1, .2, .7)
+  expect_silent(w_out <- txtRound(w))
+  expect_equivalent(w_out, c("0", "0", "1"))
+  w_out <- txtRound(w, digits = 0:2)
+  expect_equivalent(w_out, c("0", "0.2", "0.70"))
+
+  expect_error(txtRound(w, digits = 0:20))
+})
+
+
 test_that("Numbers that round to 0 should not have -, i.e. no -0.0",{
   expect_equal(txtRound(matrix(-.01), digits = 1),
                matrix("0.0"))
@@ -157,3 +173,27 @@ test_that("Character vectors work", {
 
 })
 
+
+test_that("Peter's issues raised in #34",{
+  expect_silent(txtRound(c(1, 2, 3, 4)))
+
+  expect_silent(txtRound(c(1, 2, 3, NA)))
+
+  expect_silent(txtRound(c(NA, NA, NA, NA)))
+})
+
+test_that("Scientific notation",{
+  expect_equal(txtRound("1.1234", 1), "1.1")
+
+  expect_equal(txtRound("1.1234e1", 1), "1.12e+01")
+
+  expect_equal(txtRound("1.1234e+01", 1), "1.12e+01")
+
+  expect_equal(txtRound("1.1234321e2", 2), "1.1234e+02")
+
+  # Doesn't work due to depares(substitute()) limitations
+  # expect_equal(txtRound(1.1234321e2, 2), "1.1234e+02")
+
+  expect_equal(txtRound(1.1234321e2, 2, scientific = TRUE), "1.1234e+02")
+  expect_equal(txtRound("1.1234321e2", 2, scientific = FALSE), "112.34")
+})
